/*!
 * \file CommandLine.cpp
 * \brief Implements the CommandLine class.
 * \author Joe Forte
 * \date 7/27/2008
 */

#include <assert.h>
#include "CommandLine.h"

//--------------------------------------------------------------------
void CommandLine::Parse(int argc, char *argv[])
{
	// converts the command line to a more convenient format
	for(int i = 0; i < argc; i++)
	{
		args.push_back( std::string(argv[i]) );
	}
	
	// Parses for the commands
	argType *cmdArgs = NULL;
	for(int i = 0; i < argc; i++)
	{
		assert(args[i].length() > 0);
		
		char first = args[i][0];
		if(first  == '+' || first == '-')
		{
			cmdArgs = &cmds[args[i]];
		}
		else if(cmdArgs)
		{
			cmdArgs->push_back(args[i]);
		}
	}
}

//--------------------------------------------------------------------
bool CommandLine::FindCmd(const char *cmd, std::vector<std::string> *args) const
{
	cmdMapType::const_iterator i = cmds.find( std::string(cmd) );
	if(i != cmds.end())
	{
		if(args)
			*args = i->second;
		return true;
	}
	
	return false;
}

//--------------------------------------------------------------------
int CommandLine::Find(const char *arg) const
{
	size_t len = args.size();
	for(size_t i = 0; i < len; i++)
	{
		if(args[i] == arg)
			return (int)i; 
	}
	
	return -1;
}

//--------------------------------------------------------------------
const char *CommandLine::Get(uint i) const
{
	assert(i < GetArgCount());
	return args[i].c_str();
}

//--------------------------------------------------------------------
uint CommandLine::GetArgCount() const
{
	return (uint)args.size();
}

//--------------------------------------------------------------------
uint CommandLine::GetCmdCount() const
{
	return (uint)cmds.size();
}
