/*!
 * \file DataPaths.cpp
 * \brief Implements the DataPaths static class.
 * \author Joe Forte
 * \date 8/4/2008
 */

#include "Common/Globals.h"
#include "Common/Path.h"
#include "Utility/StringUtility.h"
#include "Application/DataPaths.h"

#include "tinyxml.h"

std::map<std::string, std::string> DataPaths::paths;

//--------------------------------------------------------------------
void DataPaths::Load(const char *fileName)
{
	TiXmlDocument doc(fileName);
	if( !doc.LoadFile() )
	{
		ConError() << "DataPaths file '" << fileName << "' could not be parsed.\n";
		return;
	}
	
	TiXmlHandle hDoc(&doc);
	
	TiXmlNode *Root = hDoc.FirstChildElement().Node();
	if( !Root || Root->ValueStr() != "DataPaths")
	{
		ConError() << "DataPaths file '" << fileName << "' is improperly formatted.\n";
		return;
	}
	
	TiXmlNode *curr = Root->FirstChild();
	
	while(curr)
	{
		if(curr->Type() == TiXmlNode::ELEMENT)
		{
			TiXmlElement *elm = curr->ToElement();
			
			std::string value = elm->Value();
			ToLower(value);
			paths[value] = CreatePath(elm->GetText());
		}
		
		curr = Root->IterateChildren(curr);
	}
}

//--------------------------------------------------------------------
const std::string &DataPaths::GetPath(const char *name)
{
	std::string n = name;
	ToLower(n);
	std::map<std::string, std::string>::iterator i = paths.find(n);
	if(i != paths.end())
		return i->second;
	
	std::stringstream s;
	s << "'" << name << "' is not a valid DataPaths path name."; 
	
	const char *str = s.str().c_str();
	THROW_ERROR_TYPE(InvalidArgumentError, str);
}
