/*!
 * \file DataPaths.h
 * \brief Declares the DataPaths static class for accessing path information to data directories.
 * \author Joe Forte
 * \date 8/4/2008
 */

#ifndef DATAPATHS_H
#define DATAPATHS_H

#include <map>
#include <string>
#include "Common/Error.h"
#include "Application/DataPaths.h"

/*!
 * \class DataPaths
 * \headerfile DataPaths.h "Application/DataPaths.h"
 * \brief Static class for accessing paths to data directories.
 */
class DataPaths
{
public:
	
	/*!
	 * \brief Loads and parses an xml file extracting paths.
	 *
	 * \param[in] fileName the name of the xml file containing data path information.
	 */
	static void Load(const char *fileName);
	
	/*!
	 * \brief Gets the specified path.
	 *
	 * \param[in] name the name of the data path to retrieve.
	 *
	 * \throws InvalidArgumentError if the given name does not exist.
	 */
	static const std::string &GetPath(const char *name);
	
private:
	
	static std::map<std::string, std::string> paths;
};

#endif
