/*!
 * \file FramesPerSecond.cpp
 * \brief Implements a class that counts the number of frames per second.
 * \author Joe Forte
 * \date 3/8/2008
 */

#include <assert.h>
#include <float.h>
#include "Application/FramesPerSecond.h"

//--------------------------------------------------------------------
FramesPerSecond::FramesPerSecond()
{
	curFPS = 0.0f;
	minFPS = FLT_MAX;
	maxFPS = 0.0f;

	timer = 0.0f;
	count = 0;
}

//--------------------------------------------------------------------
void FramesPerSecond::Update(float dt)
{
	count++;
	timer += dt;
	
	if( timer >= 1.0f )
	{
		curFPS = count / timer;
		if( curFPS > maxFPS )
		{
			maxFPS = curFPS;
		}
		else if( curFPS < minFPS )
		{
			minFPS = curFPS;
		}

		count = 0;
		timer = 0.0f;
	}
}

