/*!
 * \file FramesPerSecond.h
 * \brief Declares a class that counts the number of frames per second.
 * \author Joe Forte
 * \date 3/8/2008
 */

#ifndef FRAMESPERSECOND_H
#define FRAMESPERSECOND_H

#include "Common/BaseTypes.h"

/*!
 * \class FramesPerSecond
 * \headerfile FramesPerSecond.h "Application/FramesPerSecond.h"
 */
class FramesPerSecond
{
public:
	/*!
	 * \brief Constructor.
	 */
	FramesPerSecond();
	
	/*!
	 * \brief Call once at the begining (or end) of each frame.
	 */
	void Update(float dt);

	/*!
	 * \brief Returns the current fps.
	 */
	float Get() const { return curFPS; }
	
	/*!
	 * \brief Returns the continues fps on a one second interval.
	 */
	float GetNow() const
	{ 
		if(timer == 0.0f) 
			return curFPS;
		return count / timer; 
	}

	/*!
	 * \brief Gets the min fps.
	 */
	float GetMin() const { return minFPS; }

	/*!
	 * \brief Gets the max fps.
	 */
	float GetMax() const { return maxFPS; }

private:
	float curFPS;
	float minFPS;
	float maxFPS;

	float timer;
	uint count;
};

#endif

