/*!
 * \file BaseTypes.h
 * \brief Defines base types and macros.
 * \author Joe Forte
 * \date 3/8/2008
 */

#ifndef BASETYPES_H
#define BASETYPES_H

/*********************************************************************
 *  Integer types
 *********************************************************************/
#ifndef _MSC_VER
	#include <stdint.h>
#endif

/*!
 * \typedef uint64
 * \brief A 64-bit unsigned integer.
 */
#ifdef _MSC_VER
	typedef unsigned __int64	uint64;
#else
	typedef uint64_t			uint64;
#endif

/*!
 * \typedef int64
 * \brief A 64-bit signed integer.
 */
#ifdef _MSC_VER
	typedef __int64					int64;
#else
	typedef int64_t					int64;
#endif

/*!
 * \typedef uint
 * \brief A 32-bit unsigned integer.
 */
#ifdef _MSC_VER
	typedef unsigned __int32	uint;
#else
	typedef uint32_t			uint;
#endif

/*!
 * \typedef int32
 * \brief A 32-bit signed integer.
 */
#ifdef _MSC_VER
	typedef __int32					int32;
#else
	typedef int32_t					int32;
#endif

/*!
 * \typedef uint16
 * \brief A 16-bit unsigned integer.
 */
#ifdef _MSC_VER
	typedef unsigned __int16	uint16;
#else
	typedef uint16_t			uint16;
#endif

/*!
 * \typedef int16
 * \brief A 16-bit signed integer.
 */
#ifdef _MSC_VER
	typedef __int16					int16;
#else
	typedef int16_t					int16;
#endif

/*!
 * \typedef byte
 * \brief An 8-bit unsigned integer.
 */
#ifdef _MSC_VER
	typedef unsigned __int8		byte;
#else
	typedef uint8_t				byte;
#endif

/*!
 * \typedef int8
 * \brief A 8-bit signed integer.
 */
#ifdef _MSC_VER
	typedef __int8					sbyte;
#else
	typedef int8_t					sbyte;
#endif

/*********************************************************************
 *  Macros
 *********************************************************************/

/*!
 * \def TSTR
 * \brief Constructs proper string literals depending taking into account if unicode is being used or not.
 *
 * \param[in] str the string literal.
 */
#ifdef _UNICODE
	#define TSTR( str ) L##str
	typedef wchar_t tchar;
#else
	#define TSTR( str ) str
	typedef char tchar;
#endif


#ifndef NULL
	#define NULL 0
#endif

#endif
