/*********************************************************************
 
	File: Error.h
	Data: 3/18/2008
	Desc: Declares error types.
 
 **********************************************************************/

#ifndef ERROR_H
#define ERROR_H

#include <stdexcept>
#include <sstream>
#include <string>

// Base error class for exceptions
class Error : public std::runtime_error
{
public:
	Error() : runtime_error("NOT GIVEN"), line(-1), file("UNKNOWN"), function("UNKNOWN"), message("NOT GIVEN") {}
	Error(int lineNumber, const char *fileName, const char * functionName, const char *msg)
	:
	runtime_error(msg),
	line(lineNumber),
	file(fileName),
	function(functionName),
	message(msg)
	{}
	
	virtual ~Error() throw() {}
	
	std::string ConstructVerboseMessage()
	{
		std::stringstream msg;
		
		msg << "ERROR in function '" << function << "' located in file '" << file << "' at line " << line << std::endl;
		msg << "    " << message << std::endl;
		
		return msg.str();
	}
	
	int line;
	std::string file;
	std::string function;
	std::string message;
};

class OutOfBoundsError : public Error
{
public:
	OutOfBoundsError() {}
	OutOfBoundsError(int lineNumber, const char *fileName, const char *functionName, const char *msg)
	:
	Error(lineNumber, fileName, functionName, msg)
	{}
};

class InvalidArgumentError : public Error
{
public:
	InvalidArgumentError() {}
	InvalidArgumentError(int lineNumber, const char *fileName, const char *functionName, const char *msg)
	:
	Error(lineNumber, fileName, functionName, msg)
	{}
};

#define THROW_ERROR( msg ) throw Error(__LINE__, __FILE__, __FUNCTION__, msg);
#define THROW_ERROR_TYPE(type, msg) throw type(__LINE__, __FILE__, __FUNCTION__, msg);

#endif
