/*!
 * \file FileSystem.cpp
 * \brief Implements system independent funcitons for managing the filesystem.
 * \author Joe Forte
 * \date 12/23/2008
 */

#include <fstream>
#include "Common/Globals.h"
#include "Common/FileSystem.h"

#ifdef __APPLE__
	#include <unistd.h>
	#include <stdio.h>
	#include <errno.h>
	#include <sys/stat.h>
#endif

#ifdef _WIN32
	#include "windows.h"
#endif

//--------------------------------------------------------------------
bool ChangeWorkingDirectory(const char *path)
{
	if(!path)
		return false;
	
#ifdef __APPLE__
	
	std::string finalPath = "\"";
	finalPath += path;
	finalPath += "\"";
	
	if(chdir(path) == -1)
	{
		ConError() << "\n" << strerror(errno) << "\n";
		return false;
	}
	
#endif

#ifdef _WIN32

	BOOL ret = SetCurrentDirectory(path);
	return ret != 0;

#endif

	
	return true;
}

//--------------------------------------------------------------------
std::string GetWorkingDirectory()
{
#ifdef __APPLE__
	
	char *cwd = getcwd(NULL, 0);
	
	std::string path = CreatePath(cwd);
	
	free(cwd);
	
	return path;
	
#endif

#ifdef _WIN32

	char buff[MAX_PATH];

	DWORD ret = GetCurrentDirectory(MAX_PATH, buff);

	return CreatePath(buff);

#endif
	
	return CreatePath("");
}

//--------------------------------------------------------------------
bool FileExists(const char *fileName)
{
#ifdef __APPLE__
	
	struct stat buf;
	int result = stat(fileName, &buf);
	
	return result == 0 && !(buf.st_mode & S_IFDIR); // makes sure we have opened a file and not a directory
	
#else
	
	std::ifstream stream;
	stream.open(fileName, std::ifstream::in);

	return stream.is_open();
	
#endif
}
