/*!
 * \file FileSystem.h
 * \brief Declares system independent funcitons for managing the filesystem.
 * \author Joe Forte
 * \date 12/23/2008
 */

#ifndef FILESYSTEM_H
#define FILESYSTEM_H

#include "Common/Path.h"

/*!
 * \brief Changes the applications working directory.
 *
 * \param[in] path the path to change to.
 *
 * \return true if the working directory was changed, false otherwise. 
 */
bool ChangeWorkingDirectory(const char *path);

/*!
 * \brief Gets the application current working directory
 *
 * \return the path to the current working directory
 */
std::string GetWorkingDirectory();

/*!
 * \brief Determines if the specified file exists.
 *
 * \param[in] fileName the name of the file to look for.
 *
 * \return true if the file exists, false otherwise.
 */
bool FileExists(const char *fileName);

#endif
