/*!
 * \file Path.h
 * \brief Declares system indepent functions for manipulating file system Paths. 
 * \author Joe Forte
 * \date 5/21/2008
 */

#ifndef PATH_H
#define PATH_H

#include <string>

#ifdef _WIN32
	const char PATH_SEPERATOR = '\\';
	const char INVALID_PATH_SEPERATOR = '/';
#else
	const char PATH_SEPERATOR = '/';
	const char INVALID_PATH_SEPERATOR = '\\';
#endif

//--------------------------------------------------------------------
inline std::string CreatePath(const char *str)
{
	std::string tmp = str;
	for(std::string::iterator i = tmp.begin(); i != tmp.end(); i++)
	{
		if(*i == INVALID_PATH_SEPERATOR)
			*i = PATH_SEPERATOR;
	}
	
	return tmp;
}

//--------------------------------------------------------------------
inline std::string CreatePath(const std::string &str)
{
	return CreatePath( str.c_str() );
}

//--------------------------------------------------------------------
inline std::string ConcatPath(const std::string &str1, const std::string &str2)
{
	if(str1.size() == 0)
		return str2;
	
	std::string val = str1;
	
	if(str1[str1.size() - 1] != PATH_SEPERATOR)
		val += PATH_SEPERATOR;
	
	val += str2;
	return val;
}

/*!
 * \brief Gets the path portion of the given complete path.
 *
 * \param[in] fullPath the complete path.
 *
 * \return removes the trailing file name from the path.
 */
std::string GetPathPart(const std::string &fullPath);

#endif
