/*!
 * \file GUIButton.cpp
 * \brief Implements the GUIButton class.
 * \author Joe Forte
 * \date 6/2/2008
 */

#include "GUI/GUIButton.h"
#include "Graphics/MathDraw.h"
#include "Common/Globals.h"

//--------------------------------------------------------------------
GUIButton::GUIButton() : action(NULL), bgColor(0.0f, 0.0f, 0.0f, 0.0f), xOffset(0.0f), yOffset(0.0f)
{}

//--------------------------------------------------------------------
GUIButton::~GUIButton()
{}

//--------------------------------------------------------------------
void GUIButton::OnMouseClick(const IMouse &m)
{
	DoClickAction();
}

//--------------------------------------------------------------------
void GUIButton::Paint()
{
	AABB bounds = NormToScreenCoords( GetBounds() );
	if(bgColor.a > 0.0f)
	{
		DrawQuad(bounds.CenterPosition(), bounds.Width(), bounds.Height(), true, bgColor);
	}
	
	if(font.IsValid())
	{
		Point2f p = GetPosition() + Point2f(xOffset, yOffset);
		
		font->DrawTextStr(text.c_str(), color, AABBToRect<float>(bounds), Font::ALIGN_CENTER);
	}
}

//--------------------------------------------------------------------
void GUIButton::SetText(const std::string &str, FontRef f, const Color4f &c)
{
	text = str;
	font = f;
	color = c;
}

//--------------------------------------------------------------------
void GUIButton::ChangeText(const std::string &str, bool refitToBounds)
{
	text = str;
	if(refitToBounds)
	{
		SetTextBounds(xOffset, -yOffset, GetBounds().CenterPosition());
	}
}

//--------------------------------------------------------------------
void GUIButton::SetTextBounds(float xPadding, float yPadding, const Point2f &centerPos)
{
	if(!font.IsValid())
		return;
	
	xOffset = xPadding;
	yOffset = -yPadding;
	
	Point2f dim;
	font->StringDimensions(text.c_str(), dim.x, dim.y);
	dim = ScreenToNormCoords(dim);
	
	const float w = dim.x;
	const float h = dim.y;
	AABB aabb(centerPos, w + 2.0f * xPadding, h + 2.0f * yPadding);
	SetArea(aabb);
}
