/*!
 * \file GUIButton.h
 * \brief Declares the GUIButton class.
 * \author Joe Forte
 * \date 6/2/2008
 */

#ifndef GUIBUTTON_H
#define GUIBUTTON_H

#include "GUI/GUIPanel.h"
#include "Graphics/Color.h"
#include "Graphics/Font.h"

class GUIButton;

class GUIButtonAction
{
public:
	virtual void OnClick(GUIButton *b) = 0;
};

class GUIButton : public GUIPanel
{
public:
	GUIButton();
	virtual ~GUIButton();
	
	virtual void OnMouseClick(const IMouse &m);
	
	virtual const char *GetPanelTypeName() const { return "GUI::Button"; }
	
	// Ownership of the action is taken by the button class.
	void SetAction(GUIButtonAction *a) { action = a; }
	
	void SetText(const std::string &str, FontRef f, const Color4f &c);
	void ChangeText(const std::string &str, bool refitToBounds = false);
	
	// Builds a tight fitting bounds around the currently set text with the given padding
	void SetTextBounds(float xPadding, float yPadding, const Point2f &centerPos);
	
	void SetBackgroundColor(const Color4f &c) { bgColor = c; }
	
protected:
	
	/*!
	 * \brief Does the actual rendering of the GUI element.
	 */
	virtual void Paint();
	
protected:
	
	void DoClickAction() { if(action) action->OnClick(this); }
	
	GUIButtonAction *action;
	
	std::string text;
	FontRef font;
	Color4f color;
	float xOffset;
	float yOffset;
	
	Color4f bgColor;
};

#endif
