/*!
 * \file GUIProgressBar.h
 * \brief Implements the progress bar gui element.
 * \author Joe Forte
 * \date 1/18/2009
 */

#include "Common/Globals.h"
#include "Graphics/Screen.h"
#include "Graphics/MathDraw.h"
#include "GUI/GUIProgressBar.h"

//--------------------------------------------------------------------
void GUIProgressBar::IncrementProgress(float amt)
{
	progress += amt;
	ClampInPlace(progress, 0.0f, 1.0f);
}

//--------------------------------------------------------------------
void GUIProgressBar::SetProgress(float val)
{
	progress = Clamp(val, 0.0f, 1.0f);
}

//--------------------------------------------------------------------
void GUIProgressBar::Paint()
{
	Rectf area = GetArea();
	
	Rectf bar;
	bar.x = area.x + 2.0f;
	bar.y = area.y - 2.0f;
	bar.w = (area.w - 4.0f) * progress;
	bar.h = area.h - 4.0f;
	
	Rectf bg;
	bg.x = area.x + 1.0f;
	bg.y = area.y - 1.0f;
	bg.w = area.w - 2.0f;
	bg.h = area.h - 2.0f;
	
	DrawRect(area, true, borderColor);
	DrawRect(bg, true, bgColor);
	DrawRect(bar, true, barColor);
	
	if(!innerText.empty() && innerTextFont.IsValid())
	{
		IScreen *screen = GetScreen();
		
		float w, h;
		innerTextFont->StringDimensions(innerText.c_str(), w, h);
		
		// Centers the text
		Point2f drawPos(area.x, area.y);
		drawPos.x = drawPos.x + (area.w - 4.0f - w) / 2.0f;
		drawPos.y = drawPos.y + (area.h + 4.0f - h) / 2.0f;

		Recti drawArea;
		drawArea.x = (int)bar.x;
		drawArea.y = (int)bar.y;
		drawArea.w = (int)bar.w;
		drawArea.h = (int)bar.h;
		screen->EnableDrawRegion(drawArea);
		{
			innerTextFont->DrawTextStr(innerText.c_str(), Color::Black, drawPos);
		}
		screen->DisableDrawRegion();
		
		drawArea.x += drawArea.w;
		drawArea.w = (int)(area.w - bar.w);
		screen->EnableDrawRegion(drawArea);
		{
			innerTextFont->DrawTextStr(innerText.c_str(), Color::White, drawPos);
		}
		screen->DisableDrawRegion();
	}
}
