/*!
 * \file GUIText.h
 * \brief Declares the GUIText class that.
 * \author Joe Forte
 * \date 6/2/2008
 */

#ifndef GUITEXT_H
#define GUITEXT_H

#include <string>
#include "GUI/GUIPanel.h"
#include "Graphics/Color.h"
#include "Graphics/Font.h"

/*!
 * \class GUIText
 * \headerfile GUIText.h "GUI/GUIText.h"
 * \brief GUI element that displays static text.
 */
class GUIText : public GUIPanel
{
public:
	
	/*!
	 * \brief Constructor.
	 */
	GUIText();
	
	/*!
	 * \brief Deconstructor.
	 */
	virtual ~GUIText();
	
	/*!
	 * \brief Sets the font to use when drawing text.
	 *
	 * \param[in] f the referance to the font.
	 */
	void SetFont(FontRef f);
	
	/*!
	 * \brief Sets the color to use when drawing text.
	 *
	 * \param[in] c the color.
	 */
	void SetColor(const Color4f &c) { color = c; }
	
	/*!
	 * \brief Sets the GUI elements text to display.
	 *
	 * \param[in] str the string.
	 */
	void SetText(const char *str);
	
	/*!
	 * \brief Sets the GUI elements text to display.
	 *
	 * \param[in] str the string.
	 */
	void SetText(const std::string &str);
	
	/*!
	 * \brief Gets the string type identifier for the GUI element.
	 *
	 * \return The string type identifier.
	 */
	virtual const char *GetPanelTypeName() const { return "GUI::Text"; }
	
protected:
	
	/*!
	 * \brief Does the actual rendering of the GUI element.
	 */
	virtual void Paint();
	
	/*!
	 * \brief Recomputes the bounds and layout for the panel. Called by the Refit() method.
	 */
	virtual void RecomputeLayout();
	
protected:
	
	FontRef font;
	
	std::string text;
	Color4f color;
};

#endif
