/*!
 * \file GUITextEntry.h
 * \brief Implements the text entry gui element.
 * \author Joe Forte
 * \date 1/18/2009
 */

#include "GUI/GUITextEntry.h"

//--------------------------------------------------------------------
GUITextEntry::GUITextEntry()
{}

//--------------------------------------------------------------------
GUITextEntry::GUITextEntry(GUIPanel *p) : GUIPanel(p) 
{}

//--------------------------------------------------------------------
GUITextEntry::GUITextEntry(uint len) : bufferedInput(len) 
{}

//--------------------------------------------------------------------
GUITextEntry::GUITextEntry(uint len, const Key *keys, uint n) : bufferedInput(len, keys, n) 
{}

//--------------------------------------------------------------------
const std::string &GUITextEntry::GetText() const 
{ 
	return bufferedInput.GetInput(); 
}

//--------------------------------------------------------------------
void GUITextEntry::ClearText() 
{ 
	bufferedInput.ClearInput(); 
}

//--------------------------------------------------------------------
uint GUITextEntry::GetCursorPosition() const 
{ 
	return bufferedInput.GetCursorPos(); 
}

//--------------------------------------------------------------------
uint GUITextEntry::GetMaxInputLength() const 
{ 
	return bufferedInput.GetMaxLength(); 
}

//--------------------------------------------------------------------
void GUITextEntry::OnMouseClick(const IMouse &m)
{
	RequestFocus();
}

//--------------------------------------------------------------------
void GUITextEntry::KeyboardUpdate(const IKeyboard &kb)
{
	bufferedInput.Update(kb);
}

//--------------------------------------------------------------------
void GUITextEntry::Paint() 
{
	font->DrawTextStr(GetText().c_str(), color, GetPosition());
}

//--------------------------------------------------------------------
void GUITextEntry::RecomputeLayout()
{
	float w, h;
	font->StringDimensions(GetText().c_str(), w, h);
	
	SetWidth(w);
	SetHeight(h);
}
