/*!
 * \file GUIViewport.cpp
 * \brief Implements the GUIViewport class that acts as the root to a tree of GUIPanels.
 * \author Joe Forte
 * \date 6/2/2008
 */

#include "GUI/GUIViewport.h"

//--------------------------------------------------------------------
GUIViewport::GUIViewport() : GUIPanel(NULL), mouseFocus(NULL), keyboardFocus(NULL), mouse(NULL), keyboard(NULL) {}

//--------------------------------------------------------------------
GUIViewport::~GUIViewport() {}

//--------------------------------------------------------------------
void GUIViewport::SetKeyboardFocus(GUIPanel *panel)
{
	if(keyboardFocus == panel)
		return;
	
	if(keyboardFocus)
		keyboardFocus->OnFocusLost(*keyboard);
	
	keyboardFocus = panel;
	
	if(keyboardFocus)
		keyboardFocus->OnFocusGained(*keyboard);
}

//--------------------------------------------------------------------
void GUIViewport::Update(float dt)
{
	GUIPanel::Update(dt);
	
	Point2f p = mouse->GetPosNorm();
	GUIPanel *focus = Query(p);
	if(mouseFocus)
	{
		if(mouseFocus != focus)
		{
			mouseFocus->OnMouseLeave(*mouse);
			if(focus)
				focus->OnMouseOver(*mouse);
		}
	}
	else
	{
		if(focus)
			focus->OnMouseOver(*mouse);
	}

	mouseFocus = focus;
	
	if(keyboardFocus)
	{
		if(keyboardFocus->IsActive())
			keyboardFocus->KeyboardUpdate(*keyboard);
		else
			SetKeyboardFocus(NULL);
	}

	if(mouseFocus)
	{
		if(mouse->ButtonPressed(Keys::MOUSE_BUTTON_LEFT))
		{
			mouseFocus->OnMouseClick(*mouse);
		}
		else if(mouse->ButtonReleased(Keys::MOUSE_BUTTON_LEFT))
		{
			mouseFocus->OnMouseRelease(*mouse);
			
			if(keyboardFocus && keyboardFocus != mouseFocus)
				keyboardFocus->OnFocusLost(*keyboard);
				
			keyboardFocus = mouseFocus;
			keyboardFocus->OnFocusGained(*keyboard);
		}
		else
		{
			mouseFocus->OnMouseHover(*mouse);
		}
	}
}
