/*!
 * \file GUIViewport.h
 * \brief Declares the GUIViewport class that acts as the root to a tree of GUIPanels.
 * \author Joe Forte
 * \date 6/2/2008
 */

#ifndef GUIVIEWPORT_H
#define GUIVIEWPORT_H

#include "GUI/GUIPanel.h"

class IMouse;
class IKeyboard;

class GUIViewport : public GUIPanel
{
public:
	GUIViewport();
	virtual ~GUIViewport();
	
	void SetInput(IMouse *m, IKeyboard *kb) { mouse = m; keyboard = kb; }
	
	// Returns true if the point 'p' is inside this panel 
	virtual bool InActiveArea(const Point2f &p) const { return true; }
	
	virtual const char *GetPanelTypeName() const { return "GUI::Viewport"; }
	
	void SetKeyboardFocus(GUIPanel *panel);
	
	virtual void Update(float dt);
	
protected:
	
	/*!
	 * \brief Moves up the tree until a panel that can grant focus is reached.
	 *
	 * NOTE: Do not override this method.
	 */
	virtual void InternalRequestFocus(GUIPanel *p) { SetKeyboardFocus(p); }
	
private:
	GUIPanel *mouseFocus;
	GUIPanel *keyboardFocus; // The panel that was last clicked on.
	
	IMouse *mouse;
	IKeyboard *keyboard;
};

#endif
