/*!
 * \file BackgroundEffect.h
 * \brief Declares the BackgroundEffect base class for representing niffty background effects. 
 * \author Joe Forte
 * \date 2/9/2009
 */

#ifndef BACKGROUNDEFFECT_H
#define BACKGROUNDEFFECT_H

#include "Math/MathCommon.h"

/*!
 * \class BackgroundEffect
 * \headerfile BackgroundEffect.h "Game/BackgroundEffect.h"
 * \brief Base class for background effects.
 */
class BackgroundEffect
{
public:

	/*!
	 * \brief Constructor.
	 *
	 * \param[in] size the that the effect will fill.
	 */
	BackgroundEffect(const Rectf &size) : effectSize(size) {}

	/*!
	 * \brief Deconstructor.
	 */
	virtual ~BackgroundEffect() {}

	/*!
	 * \brief Gets the size of the effect.
	 *
	 * \return the rectangle that the effect exists in.
	 */
	const Rectf &GetSize() { return effectSize; }

	/*!
	 * \brief Initializes the effect. Called once before Update and Draw are called.
	 *
	 * \return true if the initialization was successful, false otherwise.
	 */
	virtual bool Init() = 0;

	/*!
	 * \brief Updates the effect.  Called once per frame.
	 *
	 * \param[in] dt the time in seconds since the last frame.
	 */
	virtual void Update(float dt) = 0;

	/*!
	 * \brief Draws the effect.
	 */
	virtual void Draw() = 0;

private:

	Rectf effectSize;
};

#endif
