/*!
 * \file Ball.cpp
 * \brief Implements the ball class.
 * \author Joe Forte
 * \date 3/18/2008
 */

#include "Common/Globals.h"
#include "Game/ConsoleVars.h"
#include "Game/Ball.h"

//--------------------------------------------------------------------
Ball::Ball()
{	
	trail1.emitPolicy.Start();
	trail1.emitPolicy.SetFlowRate(25.0f);
	trail1.emitPolicy.position = Point2f(0.0f, 0.0f);
	trail1.drawPolicy.image = LoadImageResource("sparkle.png");
	trail1.drawPolicy.blendMode = BLENDMODE_ADDITIVE_WITH_ALPHA;
	trail1.initPolicy.color = Color::Blue;
	
	trail2.emitPolicy.Start();
	trail2.emitPolicy.SetFlowRate(25.0f);
	trail2.emitPolicy.position = Point2f(0.0f, 0.0f);
	trail2.drawPolicy.image = LoadImageResource("sparkle.png");
	trail2.drawPolicy.blendMode = BLENDMODE_ADDITIVE_WITH_ALPHA;
	trail2.initPolicy.color = Color::Gray;
	
	smokeHit.drawPolicy.image = LoadImageResource("smoke.png");
	smokeHit.drawPolicy.blendMode = BLENDMODE_ADDITIVE_WITH_ALPHA;

	hitSound.Load("ball_hit4.wav");
	hitSound.SetVolume(200);
}

//--------------------------------------------------------------------
void Ball::SetImage(const char *file)
{
	ball.Load(file);
}

//--------------------------------------------------------------------
bool Ball::Touch(PhysicsObject *obj, const PhysicsCollisionInfo &hitInfo)
{
	if(!attached)
	{
		smokeHit.initPolicy.hitDir = hitInfo.contacts[0].normal;
		smokeHit.Emit(hitInfo.contacts[0].position, 10);
		
		if(obj->GetObjectType() != POBJ_BRICK)
			hitSound.Play();
	}
	
	return true;
}

//--------------------------------------------------------------------
void Ball::Draw()
{
	if(radius > 0.0f)
	{
		trail1.Draw();
		trail2.Draw();
		
		smokeHit.Draw();
		
		ball.SetPosition( GetPosition() );
		ball.SetAngle( GetAngle() );
		ball.Draw();
		
		if(phy_drawCollisionShapes->GetInt())
			GetShapes().DrawOutline();
	}
}

//--------------------------------------------------------------------
void Ball::SetRadius(float r)
{
	if(r <= 0.0f)
	{
		radius = 0.0f;
	}
	else
	{
		radius = r;
		ball.SetHeightUniform(r * 2.0f);
		
		trail1.initPolicy.radius = r;
		trail2.initPolicy.radius = r;
	}
}

//--------------------------------------------------------------------
Circle Ball::GetCircle() const
{
	Circle c;
	c.r = radius;
	c.center = GetPosition();
	return c;
}

//--------------------------------------------------------------------
void Ball::Update(float dt)
{
	trail1.emitPolicy.position = GetPosition();
	trail2.emitPolicy.position = GetPosition();
	
	trail1.Update(dt);
	trail2.Update(dt);
	
	smokeHit.Update(dt);
}
