/*!
 * \file GUIMainMenu.h
 * \brief Declares the GUIMenuButton class.
 * \author Joe Forte
 * \date 6/2/2008
 */

#ifndef GUIMAINMENU_H
#define GUIMAINMENU_H

#include "Graphics/Font.h"
#include "GUI/GUIPanel.h"

class GUIMenuButton;
class GUIAboutMenu;
class GUIImage;
class GUIText;
class GameState;

/*!
 * \class GUIMainMenu
 * \headerfile GUIMainMenu.h "Game/GUIMainMenu.h"
 * \brief Represents the main menu (and in-game menu).
 */
class GUIMainMenu : public GUIPanel
{
public:
	
	/*!
	 * \brief Constructor.
	 *
	 * \param[in] state the game state class that the menu buttons will alter.
	 * \param[in] f the font to use for menu buttons.
	 * \param[in] aboutFont the font used for drawing about text.
	 * \param[in] aboutArea the size of the about box.
	 * \param[in] aboutTxt the about text.
	 * \param[in] versionFont the font used for the version text.
	 */
	GUIMainMenu(GameState *state, 
				FontRef f,
				FontRef aboutFont, 
				const Rectf &aboutArea, 
				const std::string &aboutTxt,
				FontRef versionFont);
	
	virtual const char *GetPanelTypeName() const { return "GUI::Game::MainMenu"; }
	
	virtual bool InActiveArea(const Point2f &p) const { return true; }

	/*!
	 * \brief Returns true if the about menu is open.
	 */
	bool IsAboutMenuOpen() const;
	
	/*!
	 * \brief Closes the about menu.
	 */
	void CloseAboutMenu();
	
	// Alters the main menu to reflect the fact that the game has been started
	void EnableInGameMode();
	void DisableInGameMode();
	
private:
	GUIImage *banner;
	
	GUIMenuButton *startButton;
	GUIMenuButton *startNewGameButton;
	GUIMenuButton *aboutButton;
	GUIMenuButton *quitButton;
	GUIMenuButton *highScoresButton;
	
	GUIMenuButton *creditsButton;

	GUIMenuButton *resumeButton;
	
	GUIText *versionText;
	
	GUIAboutMenu *about;
	
	bool inGameMode;
};

#endif
