/*!
 * \file GUIMenuButton.h
 * \brief Declares the GUIMenuButton class.
 * \author Joe Forte
 * \date 6/2/2008
 */

#ifndef GUIMENUBUTTON_H
#define GUIMENUBUTTON_H

#include "Sound/Sound.h"
#include "Game/GameState.h"
#include "GUI/GUIButton.h"

class GUIMenuButton : public GUIButton
{
public:
	GUIMenuButton();
		
	virtual void OnMouseOver(const IMouse &m);
	virtual void OnMouseLeave(const IMouse &m);
	virtual void OnMouseClick(const IMouse &m);
	virtual void OnMouseRelease(const IMouse &m);
		
	virtual void Draw();
		
	virtual const char *GetPanelTypeName() const { return "Game::MenuButton"; }
		
	// Grays out the button and makes it non-iteractive
	void Disable();
	void Enable();
		
protected:
	bool enabled;

	Sound mouseClick;
    Sound mouseRelease;
};

class GUIStateChangeButton : public GUIMenuButton
{
public:
	GUIStateChangeButton(GameState::State stateTransition, GameState *stateToChange);
		
	virtual void OnMouseRelease(const IMouse &m);
		
	virtual const char *GetPanelTypeName() const { return "Game::StateChangeButton"; }
		
private:
	GameState::State transition;
		
	GameState *state;
};

class GUIAboutMenu : public GUIPanel
{
public:
	GUIAboutMenu();
		
	void SetAboutText(FontRef f, FontRef aboutFont, const Rectf &r, const Color4f &c, const std::string &txt);
	
	virtual void KeyboardUpdate(const IKeyboard &kb);
		
	virtual bool InActiveArea(const Point2f &p) const { return true; }
		
	virtual const char *GetPanelTypeName() const { return "Game::AboutMenu"; }
		
	class GUIBackButton : public GUIMenuButton
	{
	public:
		GUIBackButton(GUIAboutMenu *m) : owner(m) {}
			
		virtual void OnMouseRelease(const IMouse &m)
		{
			GUIMenuButton::OnMouseRelease(m);

			assert(owner);
			owner->Deactivate();
			owner->SetVisibility(false);
		}
			
		virtual const char *GetPanelTypeName() const { return "GUI::AboutMenu::BackButton"; }
			
	private:
		GUIAboutMenu *owner;
	};
	
protected:
	
	/*!
	 * \brief Does the actual rendering of the GUI element.
	 */
	virtual void Paint();
		
private:
	GUIBackButton *back;
		
	std::vector<std::string> text;
	FontRef font;
	Rectf area;
	Color4f color;
};

class GUIAboutButton : public GUIMenuButton
{
public:
	GUIAboutButton(GUIAboutMenu *a);

	virtual void OnMouseRelease(const IMouse &m);
	
	virtual const char *GetPanelTypeName() const { return "Game::AboutButton"; }
		
private:
	GUIAboutMenu *about;
};

#endif
