/*!
 * \file GUIMultiplierTimer.cpp
 * \brief Implements the GUI element that represents the multiplier timer.
 * \author Joe Forte
 * \date 1/19/2009
 */

#include <sstream>
#include "Common/Globals.h"
#include "Game/GUIMultiplierTimer.h"

//--------------------------------------------------------------------
GUIMultiplierTimer::GUIMultiplierTimer()
:
timer(0.0f),
timerLength(15.0f),
multiplier(1.0f),
displayTimer(0.0f),
displayTimerLength(0.25f),
hide(true)
{	
	progressBar = new GUIProgressBar;
	progressBar->SetArea( AABB(startPos, 100.0f, 10.0f) );
	AddChild(progressBar);
	
	Rectf area = GetScreen()->GetRect();
	
	startPos = Point2f(0.0f, area.y - area.h - GetHeight() - 19.0f);
	endPos = Point2f(0.0f, area.y - area.h + GetHeight() + 20.0f);
	
	Deactivate();
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::SetTimerLength(float len)
{
	timerLength = len;
	progressBar->SetProgress(1.0f - (timer / timerLength));
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::ResetTimer()
{
	timer = 0.0f;
	progressBar->SetProgress(1.0f);
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::SetMultiplier(float val)
{
	multiplier = val;
	
	std::stringstream ss;
	ss << val << "x Multiplier";
	
	progressBar->SetInnerText(ss.str().c_str());
	
	UpdatePositions();
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::SetFont(FontRef f) 
{	
	progressBar->SetArea( AABB(startPos, 100.0f, f->LineHeight() * 1.0f) );
	progressBar->SetInnerTextFont(f);
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::Display()
{
	hide = false;
	Activate();
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::Hide()
{
	hide = true;
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::ForceHide()
{
	hide = true;
	Deactivate();
	
	displayTimer = 0.0f;
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::UpdateTimer(float dt)
{
	if(!hide)
	{
		timer = Clamp(timer + dt, 0.0f, timerLength);
		progressBar->SetProgress(1.0f - (timer / timerLength));
	}
	
	if(hide)
	{
		displayTimer = Clamp(displayTimer - dt, 0.0f, displayTimerLength);
		if(displayTimer == 0.0f)
			Deactivate();
	}
	else
	{
		displayTimer = Clamp(displayTimer + dt, 0.0f, displayTimerLength);
	}
	
	UpdatePositions();
}

//--------------------------------------------------------------------
void GUIMultiplierTimer::UpdatePositions()
{
	Point2f barPos = progressBar->GetPosition();
	barPos.y = startPos.y + std::abs(endPos.y - startPos.y) * (displayTimer / displayTimerLength);
	progressBar->SetPosition(barPos);
}
