/*!
 * \file GUIMultiplierTimer.h
 * \brief Declares the GUI element that represents the multiplier timer.
 * \author Joe Forte
 * \date 1/19/2009
 */

#ifndef GUIMULTIPLIERTIMER_H
#define GUIMULTIPLIERTIMER_H

#include "GUI/GUIPanel.h"
#include "GUI/GUIProgressBar.h"

/*!
 * \class GUIMultiplierTimer
 * \headerfile GUIMultiplierTimer.h "Game/GUIMultiplierTimer.h"
 * \brief GUIMultiplierTimer displays a decreasing timer bar.
 */
class GUIMultiplierTimer : public GUIPanel
{
public:
	
	/*!
	 * \brief Constructor.
	 */
	GUIMultiplierTimer();
	
	/*!
	 * \brief Deconstructor.
	 */
	virtual ~GUIMultiplierTimer() {}
	
	/*!
	 * \brief Sets the length of the timer.
	 *
	 * \param[in] len the length in seconds of the timer.
	 */
	void SetTimerLength(float len);
	
	/*!
	 * \brief Reset the timer.
	 */
	void ResetTimer();
	
	/*!
	 * \brief Sets the font to use when drawing text.
	 *
	 * \param[in] f the referance to the font.
	 */
	void SetFont(FontRef f);
	
	/*!
	 * \brief Sets the value of the multiplier.
	 *
	 * \param[in] val the multiplier value.
	 */
	void SetMultiplier(float val);
	
	/*!
	 * \brief Determines if the timer is done or not.
	 *
	 * \return true if the timer is complete, false otherwise.
	 */
	bool TimerComplete() const { return timer >= timerLength; }
	
	/*!
	 * \brief Displays the timer.
	 */
	void Display();
	
	/*!
	 * \brief Hides the timer.
	 */
	void Hide();
	
	/*!
	 * \brief Forcefully hides the timer skipping any animation.
	 */
	void ForceHide();
	
	/*!
	 * \brief Updates the timer.
	 *
	 * \param[in] dt the frame time in seconds.
	 */
	void UpdateTimer(float dt);
	
protected:
	
	/*!
	 * \brief Updates the positions of the GUI elements.
	 */
	void UpdatePositions();
	
	float timer;
	float timerLength;
	
	float multiplier;
	
	float displayTimer;
	float displayTimerLength;
	
	Point2f startPos;
	Point2f endPos;
	
	bool hide;
	
	GUIProgressBar *progressBar;
};

#endif
