/*!
 * \file GUIScoreBoard.h
 * \brief Declares the GUIScoreBoard class.
 * \author Joe Forte
 * \date 3/2/2009
 */

#ifndef GUISCOREBOARD_H
#define GUISCOREBOARD_H

#include "Graphics/Sprite.h"
#include "Graphics/Font.h"
#include "GUI/GUIPanel.h"
#include "GUI/GUIText.h"

class GameSettings;

#define MAX_BALLS_DISPLAYED 4u

/*!
 * \class GUIScoreBoard
 * \headerfile GUIScoreBoard.h "Game/GUIScoreBoard.h"
 * \brief GUIScoreBoard displays the games score and other game related info.
 */
class GUIScoreBoard : public GUIPanel
{
public:
	
	/*!
	 * \brief Constructor.
	 *
	 * \param[in] settings the game settings.
	 */
	GUIScoreBoard(const GameSettings &settings);
	
	/*!
	 * \brief Deconstructor.
	 */
	~GUIScoreBoard() {}
	
	/*!
	 * \brief Updates the scoreboard.
	 *
	 * \param[in] dt the time in seconds since the last frame.
	 */
	void Update(float dt);
	
	/*!
	 * \brief Increases/decrease the score by the given amount.
	 *
	 * \param[in] amount the amount to increase/decrease the score.
	 */
	void IncrementScore(int amount);
	
	/*!
	 * \brief Sets the score.
	 */
	void SetScore(int score);
	
	/*!
	 * \brief Gets the score.
	 */
	int GetScore() const { return realScore; }
	
	/*!
	 * \brief Increases the ball count by one.
	 */
	void IncrementBallCount();
	
	/*!
	 * \brief Decreases the ball count by one.
	 */
	void DecrementBallCount();
	
	/*!
	 * \brief Sets the ball count.
	 */
	void SetBallCount(uint count);
	
	/*!
	 * \brief Gets the ball count.
	 */
	int GetBallCount() const { return ballCount; }
	
protected:
	
	/*!
	 * \brief Does the actual rendering of the GUI element.
	 */
	virtual void Paint();
	
	Sprite ballImage;
	FontRef font;
	
	Rectf area;
	
	struct BallInfo
	{
		float timer;
		float size;
	};
	
	BallInfo ballInfo[MAX_BALLS_DISPLAYED];
	
	float maxBallSize;
	float ballTimer;
	
	int ballCount;
	int currentScore; // the current score that is being displayed
	int realScore; // the score that currentScore is approching
};

#endif
