/*!
 * \file GameSplashScreen.h
 * \brief Defines GameSplashScreen class used to display the initial splash screen on load.
 * \author Joe Forte
 * \date 7/22/2008
 */

#ifndef GAMESPLASHSCREEN_H
#define GAMESPLASHSCREEN_H

#include "Math/MathCommon.h"
#include "Common/Path.h"
#include "Graphics/Sprite.h"
#include "Graphics/Font.h"

const char *fmod_credit = "FMOD Sound System \xA9 copyright Firelight Technologies Pty, Ltd., 1994-2007.";

/*!
 * \class GameSplashScreen
 * \headerfile GameSplashScreen.h "Game/GameSplashScreen.h"
 * \brief Class used to display the initial splash screen.
 */
class GameSplashScreen
{
public:
	
	GameSplashScreen()
	{
		banner.Load("banner.png");
		banner.SetScale(0.5f);
		banner.SetPosition( NormToScreenCoords(Point2f(0.0f, 0.5f)) );

		SDL.Load( CreatePath("Logos/SDL.png").c_str() );
		SDL.SetPosition( NormToScreenCoords(Point2f(-0.6f, -0.75f)) );
		
		fmod.Load( CreatePath("Logos/fmod.png").c_str() );
		fmod.SetPosition( NormToScreenCoords(Point2f(0.f, -0.75f)) );
		
		box2d.Load( CreatePath("Logos/box2d.png").c_str() );
		box2d.SetPosition( NormToScreenCoords(Point2f(0.6f, -0.74f)) );
		
		fontLarge = LoadFontResource("VeraMono.ttf", 16);
		fontSmall = LoadFontResource("VeraMono.ttf", 12);
	}

	void Draw()
	{
		banner.Draw();
		box2d.Draw();
		fmod.Draw();
		SDL.Draw();

		float lineHieght = fontLarge->LineHeight();
		Point2f off(0.0f, -2.0f*lineHieght);
		fontLarge->DrawTextStr("Design, Programming & Art", Color::White, GetScreen()->GetRect(), Font::ALIGN_CENTER, off);

		off.y -= 1.5f*lineHieght;
		fontLarge->DrawTextStr("Joe Forte", Color::White, GetScreen()->GetRect(), Font::ALIGN_CENTER, off);

		off.y = fontSmall->LineHeight();
		fontSmall->DrawTextStr(fmod_credit, Color::White, GetScreen()->GetRect(), Font::ALIGN_BOTTOM, off);
	}

private:
	Sprite banner;
	Sprite box2d;
	Sprite fmod;
	Sprite SDL;

	FontRef fontLarge;
	FontRef fontSmall;
};

#endif
