/*!
 * \file GameState.cpp
 * \brief Implements the GameState class.
 * \author Joe Forte
 * \date 9/13/2008
 */

#include <cstdlib>
#include "Game/GameState.h"

//--------------------------------------------------------------------
GameState::GameState()
:
listener(NULL),
lastState(GS_STARTUP),
currState(GS_STARTUP),
nextState(GS_STARTUP)
{}

//--------------------------------------------------------------------		
void GameState::RequestStateChange(State s)
{
	if(s == GS_LAST_GAMESTATE)
	{
		RequestStateReversion();
	}
	else
	{
		nextState = s;
		if(listener)
			listener->OnStateChangeRequest(*this, s);
	}
}

//--------------------------------------------------------------------	
void GameState::ForceStateChange(State s)
{
	if(s == GS_LAST_GAMESTATE)
	{
		ForceStateReversion();
	}
	else
	{
		nextState = s;
		if(listener)
			listener->OnForcedStateChange(*this, s);
		
		Transition();
	}
}

//--------------------------------------------------------------------	
void GameState::Transition()
{
	if(listener)
		listener->OnPreStateTransition(*this, currState, nextState);
	
	lastState = currState;
	currState = nextState;
	
	if(listener)
		listener->OnPostStateTransition(*this, currState, lastState);
}
