/*!
 * \file HighScores.h
 * \brief Defines HighScores class.
 * \author Joe Forte
 * \date 9/13/2008
 */

#ifndef HIGHSCORES_H
#define HIGHSCORES_H

#include <string>
#include <vector>
#include "Graphics/Font.h"

class GameSettings;

/*!
 * \class HighScore
 * \headerfile HighScores.h "Game/HighScores.h"
 * \brief Defines a single high score.
 */
struct HighScore
{
	std::string name;
	uint score;
};

/*!
 * \class HighScores
 * \headerfile HighScores.h "Game/HighScores.h"
 * \brief Defines a class that holds and displays High Scores.
 */
class HighScores
{
public:
	
	/*!
	 * \brief Constructor.
	 */
	HighScores(const GameSettings &settings);

	/*!
	 * \brief Deconstructor.
	 */
	~HighScores();
	
	/*!
	 * \brief Loads high scores from a file.
	 */
	void LoadScoresFromFile(const char *file);
	
	/*!
	 * \brief Saves the high scores to a file.
	 */
	void SaveScoresToFile(const char *file) const;
	
	/*!
	 * \brief Clears all of the high scores.
	 */
	void ClearHighScores();

	/*!
	 * \brief Returns true if the given score is a high score.
	 */
	bool IsHighScore(uint score) const;

	/*!
	 * \brief Adds a new high score.
	 */
	void AddHighScore(const char *name, uint score);
	
	/*!
	 * \brief Clears highlighting of newly added high scores.
	 */
	void ResetHighlighting() { newlyAddedHighScore = -1; }
	
	/*!
	 * \brief Draws the high scores.
	 */
	void Draw();
	
protected:

	std::vector<HighScore> highScores; // Sorted from high to low

	uint newlyAddedHighScore;

	uint scoresToDisplay;
	
	std::string fileName;

	FontRef headerFont;
	FontRef scoreFont;
};

#endif
