/*!
 * \file LevelParser.h
 * \brief Declares the level parser class.
 * \author Joe Forte
 * \date 3/27/2008
 */

#ifndef LEVELPARSER_H
#define LEVELPARSER_H

#include <string>
#include <map>
#include "Game/Level.h"

class TiXmlElement;

class LevelParser
{
public:
	LevelParser() { Init(); }
	
	/*!
	 * \brief Loads a level from a file.
	 *
	 * \param[in] file the level file.
	 * \param[out] lvl the level object to load the level into.
	 *
	 * \return true if the level was loaded, false otherwise.
	 *
	 * NOTE: The level is not initialized after being loaded.  A call to the levels Init(...) function must be called
	 * before using the level.
	 */
	bool LoadLevel(const char *file, Level &lvl);
	
	bool ParseAttrbutes(const char *file, Level::Attributes &att);

private:

	void Init();

	typedef bool (*fnLevelFileDirectiveParser)(LevelParser &parser, TiXmlElement *elm, Level::Attributes &att);
	
	std::map<std::string, fnLevelFileDirectiveParser> directiveParserMap;
};

#endif
