/*!
 * \file MusicVisualizerEffect.cpp
 * \brief Implement the MusicVisualizerEffect background effect for visualizing music and sound.
 * \author Joe Forte
 * \date 2/11/2009
 */

#include "Graphics/MathDraw.h"
#include "Game/MusicVisualizerEffect.h"

//--------------------------------------------------------------------
bool MusicVisualizerEffect::Init()
{
	memset(bars, 0, sizeof(Bar) * SPECTRUM_SIZE);
	
	Rectf r = GetSize();
	
	barPadding = 2.0f;
	barSize = (r.w - SPECTRUM_SIZE * barPadding) / SPECTRUM_SIZE;
	barMaxHeight = r.h / 2.0f;
	barMinHeight = 2.0f;
	
	smokeWall.emitPolicy.Start();
	smokeWall.emitPolicy.SetFlowRate(200.0f);
	smokeWall.drawPolicy.image = LoadImageResource("smoke.png");
	smokeWall.drawPolicy.blendMode = BLENDMODE_ADDITIVE_WITH_ALPHA;
	smokeWall.initPolicy.color = Color4f(0.0f, 0.0f, 1.0f);
	smokeWall.initPolicy.spawnLine.a = Point2f(r.x, r.y - r.h - 40.0f);
	smokeWall.initPolicy.spawnLine.b = Point2f(r.x + r.w, r.y - r.h - 40.0f);
	
	//fountain.drawPolicy.image = LoadImageResource("smoke.png");
	//fountain.drawPolicy.blendMode = BLENDMODE_ADDITIVE_WITH_ALPHA;

	return true;
}

//--------------------------------------------------------------------
void MusicVisualizerEffect::Update(float dt)
{
	/*
	float spectrum[SPECTRUM_SIZE];
	GetSoundSpectrum(spectrum, SPECTRUM_SIZE);
	
	Rectf r = GetSize();
	
	for(int i = 0; i < SPECTRUM_SIZE; i++)
	{
		Color4f oldColor = smokeWall.initPolicy.color;
		float diff = spectrum[i] - bars[i].val;
		
		if(diff > 0.4f)
		{
			smokeWall.initPolicy.color = Color::Purple;
			smokeWall.Emit(Point2f(), 25);
		}
		else if(diff > 0.3f)
		{
			smokeWall.initPolicy.color = Color::Red;
			smokeWall.Emit(Point2f(), 25);
		}
	/*	else if(diff > 0.3f)
		{
			smokeWall.initPolicy.color = Color::Purple;
			smokeWall.Emit(Point2f(), 25);
		}
		else if(diff > 0.2f)
		{
			smokeWall.initPolicy.color = Color::Blue;
			smokeWall.Emit(Point2f(), 25);
		}*/
		/*
		smokeWall.initPolicy.color = oldColor;
		bars[i].val = spectrum[i];
	}*/
	
	//fountain.Update(dt);
	smokeWall.Update(dt);
}

//--------------------------------------------------------------------
void MusicVisualizerEffect::Draw()
{
	/*
	Rectf size = GetSize();
	
	float xStart = size.x + barPadding;
	float yStart = size.y - size.h;
	for(int i = 0; i < SPECTRUM_SIZE; i++)
	{
		DrawBar(bars[i], Point2f(xStart, yStart));
		xStart = xStart + barSize + barPadding;
	}
	*/
	
	smokeWall.Draw();
	//fountain.Draw();
}

//--------------------------------------------------------------------
void MusicVisualizerEffect::DrawBar(const Bar &b, const Point2f &p)
{
	float h = lerp(barMinHeight, barMaxHeight, b.val);
		
	Rectf r;
	r.x = p.x;
	r.y = p.y + h;
	r.h = h;
	r.w = barSize;
		
	DrawRect(r, true, Color::White);
}
