/*!
 * \file TextParticleSystem.cpp
 * \brief Implements the TextParticleSystem class.
 * \author Joe Forte
 * \date 8/17/2008
 */

#include <assert.h>
#include "Game/TextParticleSystem.h"

//--------------------------------------------------------------------
TextParticleSystem::TextParticleSystem()
{
	func = DefaultUpdateFunc;
}

//--------------------------------------------------------------------
void TextParticleSystem::Update(float dt)
{
	std::vector<TextParticle>::iterator i = particles.begin();
	while(i != particles.end())
	{
		i->age += dt;
		if(i->age > i->lifeTime)
		{
			i = particles.erase(i);
		}
		else
		{
			assert(func);
			func(*i, dt);
			i++;
		}
	}
}

//--------------------------------------------------------------------
void TextParticleSystem::Emit(const std::string &str, const Point2f &pos, const Color4f &c)
{
	TextParticle p;
	p.text = str;
	p.position = pos;
	p.color = c;
	p.age = 0.0f;
	p.lifeTime = lifeTime;
	
	particles.push_back(p);
}

//--------------------------------------------------------------------
void TextParticleSystem::SetAttributes(FontRef f, float maxAge)
{
	font = f;
	lifeTime = maxAge;
}

//--------------------------------------------------------------------
void TextParticleSystem::Draw() const
{
	for(std::vector<TextParticle>::const_iterator i = particles.begin(); i != particles.end(); i++)
	{
		font->DrawTextStr(i->text.c_str(), i->color, i->position); 
	}
}

//--------------------------------------------------------------------
void TextParticleSystem::Clear()
{
	particles.clear();
}

//--------------------------------------------------------------------
void TextParticleSystem::DefaultUpdateFunc(TextParticle &p, float dt)
{
	p.color.a = 1.0f - (p.age / p.lifeTime);
}
