/*!
 * \file ParticleSystemExt.cpp
 * \brief Implements the ParticleSystemExt policies.
 * \author Joe Forte
 * \date 9/1/2008
 */

#include <SDL_opengl.h>
#include "Graphics/ParticleSystemExt.h"
#include "Common/Globals.h"

//--------------------------------------------------------------------
void AnimatedParticleDrawPolicy::Init(uint maxParticles) {}

//--------------------------------------------------------------------
void AnimatedParticleDrawPolicy::Draw(const std::vector<size_t> &active, const std::vector<AnimatedParticle> &particleStore)
{
	
	// TODO: We still get good performace with 100's of particles but this is horribly inefficent.  Make Better.
	
	ImageRef im = image.GetImage();

	if(!im.IsValid())
		return;

	glBindTexture(GL_TEXTURE_2D, im->GetOpenGLID());

	float width = (float)im->Width();
	float height = (float)im->Height();

	GetScreen()->BeginBlendMode(blendMode);
	
	glMatrixMode(GL_MODELVIEW);
	glPushMatrix();
	glLoadIdentity();

	glBegin(GL_QUADS);
	
	uint len = (uint)active.size();
	for(uint i = 0; i < len; i++)
	{
		const AnimatedParticle &prt = particleStore[ active[i] ];
		const Point2f &p = prt.pos;
		
		float w = prt.width / 2.0f;
		float h = prt.height / 2.0f;

		float s = std::sin(prt.angle);
		float c = std::cos(prt.angle);

		float wc = w*c; float ws = w*s;
		float hs = h*s; float hc = h*c;

		const AnimatedSprite::Animation &anim = image.GetAnimation(prt.animation);
		const Rectf &rect = anim.frames[prt.frame].area;

		float u0 = rect.x / width;             float u1 = (rect.x + rect.w) / width;
		float v0 = (rect.y + rect.h) / height; float v1 = rect.y / height;
		
		glColor4f(prt.color.r, prt.color.g, prt.color.b, prt.color.a);
		
		glTexCoord2f(u0, v0);
		glVertex2f(p.x - wc + hs, p.y - ws - hc);
		
		glTexCoord2f(u1, v0);
		glVertex2f(p.x + wc + hs, p.y + ws - hc);
		
		glTexCoord2f(u1, v1);
		glVertex2f(p.x + wc - hs, p.y + ws + hc);
		
		glTexCoord2f(u0, v1);
		glVertex2f(p.x - wc - hs, p.y - ws + hc);
	}
	
	glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
	
	glEnd();

	glPopMatrix();
	glBindTexture(GL_TEXTURE_2D, 0);
	
	GetScreen()->EndBlendMode();
}
