/*!
 * \file ParticleSystemExt.h
 * \brief Declares Extensions to the policy based ParticleSystem.
 * \author Joe Forte
 * \date 9/1/2008
 */

#ifndef PARTICLESYSTEMEXT_H
#define PARTICLESYSTEMEXT_H

#include "Graphics/ParticleSystem.h"
#include "Graphics/AnimatedSprite.h"

/*!
 * \struct AnimatedParticle
 * \headerfile ParticleSystemExt.h "Graphics/ParticleSystemExt.h"
 * \brief A basic struct for Particles that allows for particles with animated textures.
 */
struct AnimatedParticle : public Particle
{
	float frameTimer;
	uint frame;

	uint animation;
};

/*!
 * \class AnimatedParticleDrawPolicy
 * \headerfile ParticleSystem.h "Graphics/ParticleSystem.h"
 * \brief A draw policy for drawing particles of type \e AnimatedParticle.
 */ 
class AnimatedParticleDrawPolicy
{
public:
	
	/*!
	 * \brief Default constructor.
	 */
	AnimatedParticleDrawPolicy() : blendMode(BLENDMODE_ALPHA) {}
	
	/*!
	 * \brief Called one at initialization.
	 *
	 * \param[in] maxParticles the maximum number of particles that will ever be drawn at a time.
	 */
	void Init(uint maxParticles);
	
	/*!
	 * \brief Draws the active set of particles.
	 *
	 * \param[in] active a vector of indices into the \a particleStore of the particles to draw.
	 * \param[in] particleStore a vector holding all of the particles (active and dead).
	 */
	void Draw(const std::vector<size_t> &active, const std::vector<AnimatedParticle> &particleStore);
	
	AnimatedSprite image;
	BlendMode blendMode; /*<! The BlendMode to use when rendering the particles.  Defaults to BLENDMODE_ALPHA. */
};

#endif
