/*********************************************************************
 
	File: Pointer.h
	Data: 3/27/2008
	Desc: Declares the smart pointer class Pointer.
 
**********************************************************************/

#ifndef _POINTER_H
#define _POINTER_H

#include "Common/BaseTypes.h"

class ReferenceCounter 
{
public:
	ReferenceCounter() : refCount(0) {}
	
	void IncrementRefCount() const { refCount++; }
	void DecrementRefCount() const { refCount--; }
	uint GetRefCount() const { return refCount; }
	
private:
	mutable uint refCount;
};

// Pointer class expects type T to inherite from ReferanceCounter 
template<class T>
class Pointer
{
public:
	Pointer() : obj(NULL) {}
	Pointer(T *object) : obj(object)
	{
		IncRefCount();
	}
	
	Pointer(const Pointer &ptr)
	{
		obj = ptr.Get();
		IncRefCount();
	}
	
	~Pointer()
	{
		DecRefCount();
	}
	
	T &operator*()
	{
		return *obj;
	}
	
	const T &operator*() const
	{
		return *obj;
	}
	
	T *operator->()
	{
		return obj;
	}
	
	const T *operator->() const
	{
		return obj;
	}
	
	Pointer &operator=(T *object)
	{
		if(object != obj)
		{
			DecRefCount();
			obj = object;
			IncRefCount();
		}
		return *this;
	}
	
	Pointer &operator=(const Pointer &object)
	{
		if(object != obj)
		{
			DecRefCount();
			obj = object.Get();
			IncRefCount();
		}
		return *this;
	}
	
	operator Pointer<const T> ()
	{
		return Pointer<const T>((const T*)obj);
	}
	
	operator bool () const
	{
		return obj != NULL;
	}
	
	bool operator==(const T *other) const
	{
		return obj == other;
	}
	
	bool operator!=(const T *other) const
	{
		return obj != other;
	}
	
	bool operator==(const Pointer &ptr) const
	{
		return obj == ptr.Get();
	}
	
	bool operator!=(const Pointer &ptr) const
	{
		return obj != ptr.Get();
	}
	
	T *Get() const
	{
		return obj;
	}
	
private:
	
	void DecRefCount()
	{
		if(obj)
		{
			obj->DecrementRefCount();
			if(obj->GetRefCount() == 0)
			{
				delete obj;
				obj = NULL;
			}
		}
	}
	
	void IncRefCount()
	{
		if(obj)
		{
			obj->IncrementRefCount();
		}
	}
	
	T *obj;
};

#endif
