/*********************************************************************
 
	File: PhysicsBody.cpp
	Data: 3/18/2008
	Desc: Implements the PhysicsBody class.
 
**********************************************************************/

#include <assert.h>
#include "Physics/PhysicsWorld.h"
#include "Physics/PhysicsObject.h"
#include "Physics/PhysicsBody.h"

#include <Box2D.h>

//--------------------------------------------------------------------------------------
void PhysicsBody::ApplyForce(const Vector2f &f)
{
	assert(body);

	b2Vec2 force(f.x, f.y);
	body->ApplyForce(force, body->GetLocalCenter());
}

//--------------------------------------------------------------------------------------
void PhysicsBody::ApplyImpulse(const Vector2f &im)
{
	assert(body);
	
	b2Vec2 impulse(im.x, im.y);
	body->ApplyImpulse(impulse, body->GetLocalCenter());
}

//--------------------------------------------------------------------------------------
Point2f PhysicsBody::GetPosition() const
{
	assert(body);

	b2Vec2 p = body->GetPosition();
	return Point2f(p.x, p.y);
}

//--------------------------------------------------------------------------------------
void PhysicsBody::SetPosition(const Point2f &p)
{
	assert(body);

	b2Vec2 pos(p.x, p.y);
	body->SetXForm(pos, body->GetAngle());
}

//--------------------------------------------------------------------------------------
Vector2f PhysicsBody::GetVelocity() const
{
	assert(body);

	b2Vec2 v = body->GetLinearVelocity();
	return Vector2f(v.x, v.y);
}

//--------------------------------------------------------------------------------------
void PhysicsBody::SetVelocity(const Vector2f &v)
{
	assert(body);

	b2Vec2 vel(v.x, v.y);
	body->SetLinearVelocity(vel);
}

//--------------------------------------------------------------------------------------
float PhysicsBody::GetAngle() const
{
	assert(body);

	return (float)body->GetAngle();
}

//--------------------------------------------------------------------------------------
PhysicsObject *PhysicsBody::GetOwner() const
{
	assert(body);
	
	PhysicsObject *obj = reinterpret_cast<PhysicsObject*>(body->GetUserData());
	assert(obj);

	return obj;
}
