/*********************************************************************
 
	File: PhysicsBody.h
	Data: 3/18/2008
	Desc: Declares the PhysicsBody class.
 
**********************************************************************/

#ifndef PHYSICSBODY_H
#define PHYSICSBODY_H

#include "Common/BaseTypes.h"
#include "Math/Vector.h"
#include "Math/Point.h"

class PhysicsWorld;
class PhysicsShape;
class PhysicsObject;

// Box2D types
class b2Body;

class PhysicsBody
{
public:
	PhysicsBody() : body(NULL) {}
	PhysicsBody(b2Body *b) : body(b) {}
	~PhysicsBody() { /* the owner of this body is expected to clean up after it */ }
		
	void ApplyForce(const Vector2f &f);
	
	/*!
	 * \brief Applys an impulse to the objects center of mass.
	 *
	 * \param[in] im the impulse.
	 */
	void ApplyImpulse(const Vector2f &im);
		
	Point2f GetPosition() const;
	void SetPosition(const Point2f &p);
		
	Vector2f GetVelocity() const;
	void SetVelocity(const Vector2f &v);
	
	float GetAngle() const;

	PhysicsObject *GetOwner() const;

	bool IsValid() const { return body != NULL; }
	
	void InValidate() { body = NULL; }
		
	b2Body *GetBox2DBody() const { return body; }
		
protected:
	b2Body *body;
};

#endif
