/*********************************************************************
 
	File: FormattedText.h
	Data: 6/2/2008
	Desc: Implements the FormattedText class.
 
**********************************************************************/

#include <assert.h>
#include "Utility/StringUtility.h"
#include "Utility/FormattedText.h"

//--------------------------------------------------------------------
int FormatText(const char *str, FontRef f, const Rectf &area, std::vector<std::string> &text)
{
	std::vector<std::string> txt; 
	int num = FormatText(str, f, txt);
	
	text = txt;
	
	return num;
}

//--------------------------------------------------------------------
int FormatText(const char *str, FontRef f, std::vector<std::string> &text)
{
	int num = 0;
	
	std::string line = str;
	
	uint i = 0;
	uint start = 0;
	uint len = 0;
	while(line[i])
	{
		if(line[i] == '\n')
		{
			text.push_back(line.substr(start, len));
			num++;
			start = i + 1;
			len = 0;
			i++;
		}
		else if(line[i] == '\t')
		{
			line.replace(i, 1, "    ");
			len = len + 4;
			i = i + 4;
		}
		else
		{
			len++;
			i++;
		}
	}
	
	if(len > 0)
	{
		text.push_back(line.substr(start, len));
		num++;
	}
	
	return num;
}

//--------------------------------------------------------------------
void DrawFormattedText(FontRef f, const Point2f &p, const Color4f &c, const std::vector<std::string> &text)
{
	DrawFormattedText(f, p, c, text, 0, (uint)text.size());
}

//--------------------------------------------------------------------
void DrawFormattedText(FontRef f, const Point2f &p, const Color4f &c, const std::vector<std::string> &text, uint offset, uint count)
{
	if(offset >= text.size())
		return;
	
	float lineHeight = f->LineHeight();
	Point2f drawPos = NormToScreenCoords(p);
	
	std::vector<std::string>::const_iterator i = text.begin() + offset;
	while(i != text.end() && count > 0)
	{
		f->DrawTextStr(i->c_str(), c, drawPos);
		drawPos.y -= lineHeight;
		count--;
	}
}

//--------------------------------------------------------------------
int WrapText(FontRef f, float width, const std::string &str, std::vector<std::string> &txt)
{
	std::vector<std::string> words;
	Split(str, " ", words, false);
	
	return WrapText(f, width, words, txt);
}

//--------------------------------------------------------------------
int WrapText(FontRef f, float width, const std::vector<std::string> &words, std::vector<std::string> &txt)
{
	assert(f.IsValid());
	
	size_t count = 0;
	size_t wordCount = words.size();
	
	float toFill = width;
	std::string currLine = "";
	
	size_t i = 0;
	while(i < wordCount)
	{
		toFill -= f->StringWidth(words[i].c_str());
		if( toFill >= 0.0f || (currLine == "" && toFill < 0.0f) )
		{
			currLine += words[i];
			i++;
		}
		else
		{
			txt.push_back(currLine);
			toFill = width;
			currLine = "";
			count++;
		}
	}
	
	if(currLine != "")
	{
		txt.push_back(currLine);
		count++;
	}
	
	return (int)count;
}
